@@ -1,4 +1,5 @@
 """Configuration Helpers for TurboGears 2"""
+
 import atexit
 import os
 import logging
@@ -103,7 +104,7 @@ class AppConfig(Bunch):
 
     AppConfig instances have a number of methods that are meant to be
     overridden by users who wish to have finer grained control over
-    the setup of the WSGI envirnment in which their application is run.
+    the setup of the WSGI environment in which their application is run.
 
     This is the place to configure custom routes, transaction handling,
     error handling, etc.
@@ -134,7 +135,7 @@ class AppConfig(Bunch):
         self.use_transaction_manager = True
         self.use_toscawidgets2 = False
 
-        #Registy for functions to be called on startup/teardown
+        # Registry for functions to be called on startup/teardown
         self.call_on_startup = []
         self.call_on_shutdown = []
         # The codes TG should display an error page for. All other HTTP errors are
@@ -144,7 +145,6 @@ class AppConfig(Bunch):
         #override this variable to customize how the tw2 middleware is set up
         self.custom_tw2_config = {}
 
-
     def setup_startup_and_shutdown(self):
         for cmd in self.call_on_startup:
             if callable(cmd):
@@ -196,9 +196,7 @@ class AppConfig(Bunch):
 
         #see http://trac.turbogears.org/ticket/2247
         if asbool(config['debug']):
-            warnings.simplefilter("ignore")
             config['pylons.strict_tmpl_context'] = True
-            warnings.resetwarnings()
         else:
             config['pylons.strict_tmpl_context'] = False
         self.after_init_config()
@@ -370,15 +368,17 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
 
     def setup_chameleon_genshi_renderer(self):
         """Setup a renderer and loader for the chameleon.genshi engine."""
-        from chameleon.genshi.loader import TemplateLoader as ChameleonLoader
-        from tg.render import render_chameleon_genshi
+        from tg.render import RenderChameleonGenshi
 
-        loader = ChameleonLoader(search_path=self.paths.templates,
+        if config.get('use_dotted_templatenames', True):
+            from tg.dottednames.chameleon_genshi_lookup \
+                import ChameleonGenshiTemplateLoader as TemplateLoader
+        else:
+            from chameleon.genshi.loader import TemplateLoader
+        loader = TemplateLoader(search_path=self.paths.templates,
                                 auto_reload=self.auto_reload_templates)
 
-        config['pylons.app_globals'].chameleon_genshi_loader = loader
-
-        self.render_functions.chameleon_genshi = render_chameleon_genshi
+        self.render_functions.chameleon_genshi = RenderChameleonGenshi(loader)
 
     def setup_genshi_renderer(self):
         """Setup a renderer and loader for Genshi templates.
@@ -387,32 +387,28 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
         filter, template loader
 
         """
-        from tg.dottednames.genshi_lookup import GenshiTemplateLoader
-        from tg.render import render_genshi
+        from tg.render import RenderGenshi
         from genshi.filters import Translator
 
         def template_loaded(template):
             """Plug-in our i18n function to Genshi, once the template is loaded.
 
-            This function will be called by genshi TemplateLoader after
+            This function will be called by the Genshi TemplateLoader after
             loading the template.
 
             """
             template.filters.insert(0, Translator(ugettext))
 
-        if not config.get('use_dotted_templatenames', True):
-            from genshi.template import TemplateLoader
-            loader = TemplateLoader(search_path=self.paths.templates,
-                                    auto_reload=self.auto_reload_templates,
-                                    callback=template_loaded)
+        if config.get('use_dotted_templatenames', True):
+            from tg.dottednames.genshi_lookup \
+                import GenshiTemplateLoader as TemplateLoader
         else:
-            loader = GenshiTemplateLoader(search_path=self.paths.templates,
-                                          auto_reload=self.auto_reload_templates,
-                                          callback=template_loaded)
+            from genshi.template import TemplateLoader
+        loader = TemplateLoader(search_path=self.paths.templates,
+                                auto_reload=self.auto_reload_templates,
+                                callback=template_loaded)
 
-        config['pylons.app_globals'].genshi_loader = loader
-
-        self.render_functions.genshi = render_genshi
+        self.render_functions.genshi = RenderGenshi(loader)
 
     def setup_kajiki_renderer(self):
         """Setup a renderer and loader for the fastpt engine."""
@@ -427,9 +423,20 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
         from jinja2 import ChoiceLoader, Environment, FileSystemLoader
         from tg.render import render_jinja
 
+        if not 'jinja_extensions' in self :
+            self.jinja_extensions = []
+
+        # TODO: Load jinja filters automatically from given modules
+        if not 'jinja_filters' in self:
+            self.jinja_filters = []
+
         config['pylons.app_globals'].jinja2_env = Environment(loader=ChoiceLoader(
                  [FileSystemLoader(path) for path in self.paths['templates']]),
-                 auto_reload=self.auto_reload_templates)
+                 auto_reload=self.auto_reload_templates, extensions=self.jinja_extensions)
+
+        # Add jinja filters
+        config['pylons.app_globals'].jinja2_env.filters = self.jinja_filters
+
         # Jinja's unable to request c's attributes without strict_c
         warnings.simplefilter("ignore")
         config['pylons.strict_c'] = True
@@ -843,6 +850,10 @@ double check that you have base_config['beaker.session.secret'] = 'mysecretsecre
             app = TGApp()
             if wrap_app:
                 app = wrap_app(app)
+
+            avoid_sess_touch = config.get('beaker.session.tg_avoid_touch', 'false')
+            config['beaker.session.tg_avoid_touch'] = asbool(avoid_sess_touch)
+
             app = self.add_core_middleware(app)
 
             if self.use_toscawidgets:
