@@ -9,10 +9,10 @@ import formencode
 import pylons
 import pylons.i18n
 from pylons.i18n import add_fallback, LanguageError, get_lang
+from pylons.i18n import ugettext, ungettext, lazy_ugettext
 from pylons.configuration import config
 from pylons import session
 
-
 log = logging.getLogger(__name__)
 
 
@@ -42,10 +42,14 @@ def setup_i18n():
     Should only be manually called if you override controllers function.
 
     """
-    if pylons.session:
+    session_ = pylons.session._current_obj()
+    if session_:
+        session_existed = session_.accessed()
         # If session is available, we try to see if there are languages set
-        languages = pylons.session.get(
-            config.get('lang_session_key', 'tg_lang'))
+        languages = session_.get(config.get('lang_session_key', 'tg_lang'))
+        if not session_existed and config.get('beaker.session.tg_avoid_touch'):
+            session_.__dict__['_sess'] = None
+
         if languages:
             if isinstance(languages, basestring):
                 languages = [languages]
@@ -109,5 +113,6 @@ def set_formencode_translation(languages):
 
 
 __all__ = [
-    "setup_i18n", "set_lang", "get_lang", "add_fallback", "set_temporary_lang"
-]
\ No newline at end of file
+    "setup_i18n", "set_lang", "get_lang", "add_fallback", "set_temporary_lang",
+    "ugettext", "lazy_ugettext", "ungettext"
+]
