@@ -9,12 +9,14 @@ try:
     from repoze.what import predicates
 except ImportError:
     predicates = []
-    
+
 from webhelpers.html import literal
 
 import tg
 from tg.configuration import Bunch
 
+from webhelpers.html import literal
+
 #monkey patch alert!
 import pylons
 def my_pylons_globals():
@@ -60,8 +62,7 @@ def my_pylons_globals():
         N_=pylons.i18n.N_
     )
 
-    # If the session was overriden to be None, don't populate the session
-    # var
+    # If the session was overridden to be None, don't populate the session var
     econf = pylons.config['pylons.environ_config']
     if 'beaker.session' in pylons.request.environ or \
         ('session' in econf and econf['session'] in pylons.request.environ):
@@ -174,8 +175,8 @@ def _get_tg_vars():
         h = h,
         tg = tg_vars
         )
-    #Allow users to provide a callable that defines extra vars to be
-    #added to the template namespace
+    # Allow users to provide a callable that defines extra vars to be
+    # added to the template namespace
     variable_provider = config.get('variable_provider', None)
     if variable_provider:
         root_vars.update(variable_provider())
@@ -198,48 +199,149 @@ def render(template_vars, template_engine=None, template_name=None, **kwargs):
         template_vars={}
 
     if template_engine != "json" and template_engine != 'amf':
-        #Get the extra vars, and merge in the vars from the controller
+        # Get the extra vars, and merge in the vars from the controller
         tg_vars = _get_tg_vars()
         tg_vars.update(template_vars)
         template_vars = tg_vars
 
     if not render_function:
-        # getting the default renderer. (this is only if no engine was defined
-        # in the @expose()
+        # getting the default renderer, if no engine was defined in @expose()
         render_function = config['render_functions'][config['default_renderer']]
 
     return render_function(template_name, template_vars, **kwargs)
 
-def render_chameleon_genshi(template_name, template_vars, **kwargs):
-    """Render the template_vars with the chameleon.genshi template"""
-    # here we use the render genshi function because it should be api compliant
-    return render_genshi(template_name, template_vars, **kwargs)
+
+class RenderChameleonGenshi(object):
+    """Singleton that can be called as the Chameleon-Genshi render function."""
+
+    format_for_content_type = {
+        'text/plain': 'text',
+        'text/css': 'text',
+        'text/html': 'xml',
+        'text/xml': 'xml',
+        'application/xml': 'xml',
+        'application/xhtml+xml': 'xml',
+        'application/atom+xml': 'xml',
+        'application/rss+xml': 'xml',
+        'application/soap+xml': 'xml',
+        'image/svg+xml': 'xml'}
+
+    def __init__(self, loader):
+        self.load_template = loader.load
+
+    def __call__(self, template_name, template_vars, **kwargs):
+        """Render the template_vars with the Chameleon-Genshi template."""
+
+        # Gets template format from content type or from config options
+        format = kwargs.get('format')
+        if not format:
+            format = self.format_for_content_type.get(response.content_type)
+            if not format:
+                format = config.get('templating.chameleon.genshi.format')
+                if not format:
+                    format = config.get('templating.genshi.method')
+                    if not format or format not in ('xml', 'text'):
+                        format = 'xml'
+
+        def render_template():
+            template_vars.update(my_pylons_globals())
+            template = self.load_template(template_name, format=format)
+            return literal(template.render(**template_vars))
+
+        return templating.cached_template(
+            template_name, render_template,
+            ns_options=('doctype', 'method'), **kwargs)
 
 
-# demand load these items from Genshi if needed
-HTML = XML = None
-def render_genshi(template_name, template_vars, **kwargs):
-    """Render the template_vars with the Genshi template"""
-    global HTML, XML
-    if not HTML or not XML:
-        from genshi import HTML, XML
+class RenderGenshi(object):
+    """Singleton that can be called as the Genshi render function."""
 
-    template_vars.update(HTML=HTML, XML=XML)
+    genshi_functions = {} # auxiliary Genshi functions loaded on demand
 
-    if config.get('use_dotted_templatenames', False):
-        template_name = tg.config['pylons.app_globals'
-                ].dotted_filename_finder.get_dotted_filename(
-                        template_name,
-                        template_extension='.html')
+    doctypes_for_methods = {
+        'html': 'html-transitional',
+        'xhtml': 'xhtml-transitional'}
 
-    if 'method' not in kwargs:
-        kwargs['method'] = {'text/xml': 'xml', 'text/plain': 'text'}.get(
-            response.content_type, config.get('templating.genshi.method', 'xhtml'))
-    # (in a similar way, we could pass other serialization options when they
-    # will be supported - see http://pylonshq.com/project/pylonshq/ticket/613)
+    doctypes_for_content_type = {
+        'text/html': ('html', 'html-transitional',
+        'html-frameset', 'html5',
+        'xhtml', 'xhtml-strict',
+        'xhtml-transitional', 'xhtml-frameset'),
+        'application/xhtml+xml': ('xhtml', 'xhtml-strict',
+        'xhtml-transitional',
+        'xhtml-frameset', 'xhtml11'),
+        'image/svg+xml': ('svg', 'svg-full', 'svg-basic', 'svg-tiny')
+        }
 
-    return templating.render_genshi(template_name, extra_vars=template_vars,
-                                    **kwargs)
+    methods_for_content_type = {
+        'text/plain': ('text',),
+        'text/css': ('text',),
+        'text/html': ('html', 'xhtml'),
+        'text/xml': ('xml', 'xhtml'),
+        'application/xml': ('xml', 'xhtml'),
+        'application/xhtml+xml': ('xhtml',),
+        'application/atom+xml': ('xml',),
+        'application/rss+xml': ('xml',),
+        'application/soap+xml': ('xml',),
+        'image/svg+xml': ('xml',)}
+
+    def __init__(self, loader):
+        if not self.genshi_functions:
+            from genshi import HTML, XML
+            self.genshi_functions.update(HTML=HTML, XML=XML)
+        self.load_template = loader.load
+
+    @staticmethod
+    def method_for_doctype(doctype):
+        method = 'xhtml'
+        if doctype:
+            if doctype.startswith('html'):
+                method = 'html'
+            elif doctype.startswith('xhtml'):
+                method = 'xhtml'
+            elif doctype.startswith('svg'):
+                method = 'xml'
+            else:
+                method = 'xhtml'
+        return method
+
+    def __call__(self, template_name, template_vars, **kwargs):
+        """Render the template_vars with the Genshi template."""
+        template_vars.update(self.genshi_functions)
+
+        # Gets document type from content type or from config options
+        doctype = kwargs.get('doctype')
+        if not doctype:
+            doctype = config.get('templating.genshi.doctype')
+            if not doctype:
+                method = kwargs.get('method') or config.get(
+                    'templating.genshi.method') or 'xhtml'
+                doctype = self.doctypes_for_methods.get(method)
+            doctypes = self.doctypes_for_content_type.get(response.content_type)
+            if doctypes and (not doctype or doctype not in doctypes):
+                doctype = doctypes[0]
+            kwargs['doctype'] = doctype
+
+        # Gets rendering method from content type or from config options
+        method = kwargs.get('method')
+        if not method:
+            method = config.get('templating.genshi.method')
+            if not method:
+                method = self.method_for_doctype(doctype)
+            methods = self.methods_for_content_type.get(response.content_type)
+            if methods and (not method or method not in methods):
+                method = methods[0]
+            kwargs['method'] = method
+
+        def render_template():
+            template_vars.update(my_pylons_globals())
+            template = self.load_template(template_name)
+            return literal(template.generate(**template_vars).render(
+                    doctype=doctype, method=method, encoding=None))
+
+        return templating.cached_template(
+            template_name, render_template,
+            ns_options=('doctype', 'method'), **kwargs)
 
 
 def render_mako(template_name, template_vars, **kwargs):
@@ -249,13 +351,16 @@ def render_mako(template_name, template_vars, **kwargs):
 
     return templating.render_mako(template_name, extra_vars=template_vars, **kwargs)
 
+
 def render_jinja(template_name, template_vars, **kwargs):
     return templating.render_jinja2(template_name, extra_vars=template_vars,
                                    **kwargs)
 
+
 def render_json(template_name, template_vars, **kwargs):
     return tg.json_encode(template_vars)
 
+
 def render_kajiki(template_name, extra_vars=None, cache_key=None,
                   cache_type=None, cache_expire=None, method='xhtml'):
     """Render a template with Kajiki
@@ -282,4 +387,3 @@ def render_kajiki(template_name, extra_vars=None, cache_key=None,
                            cache_type=cache_type, cache_expire=cache_expire,
                            ns_options=('method'), method=method)
 
-
